@@ -6,5 +6,5 @@ my $dst = shift || die("Pass destination IP");
 use Net::Libdnet::Intf;
 
 my $h = Net::Libdnet::Intf->new;
-my $info = $h->getDst($dst);
+my $info = $h->getDst($dst) or die("FATAL: getDst");
 print $info->print."\n";
