@@ -1,5 +1,5 @@
 #
-# $Id: Arp.pm 31 2011-01-12 12:52:47Z gomor $
+# $Id: Arp.pm,v c57765ed0538 2024/10/28 15:05:03 gomor $
 #
 package Net::Libdnet::Arp;
 use strict; use warnings;
@@ -64,10 +64,10 @@ Net::Libdnet::Arp - high level API to access libdnet arp_* functions
 
    use Net::Libdnet::Arp;
 
-   my $h      = Net::Libdnet::Arp->new;
-   my $mac    = $h->get('10.0.0.1');
-   my $sucess = $h->add('10.0.0.1', '00:11:22:33:44:55');
-   my $sucess = $h->delete('10.0.0.1', '00:11:22:33:44:55');
+   my $h       = Net::Libdnet::Arp->new;
+   my $mac     = $h->get('10.0.0.1');
+   my $success = $h->add('10.0.0.1', '00:11:22:33:44:55');
+   my $success = $h->delete('10.0.0.1', '00:11:22:33:44:55');
 
    my $data;
    $h->loop(\&arp_print, \$data);
@@ -115,6 +115,6 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the BSD license. See LICENSE file in the source distribution archive.
 
-Copyright (c) 2008-2011, Patrice <GomoR> Auffret
+Copyright (c) 2008-2024, Patrice <GomoR> Auffret
 
 =cut
